camelot.camelot.view.controls.editors.Many2OneEditor.CompletionsModel

Package camelot :: Package camelot :: Package view :: Package controls :: Module editors :: Class Many2OneEditor :: Class CompletionsModel |
[hide private]
[frames] | no frames]

# Class CompletionsModel

source code

Instance Methods | [hide private]
__init__(self, parent=None) | source code
setCompletions(self, completions) | source code
data(self, index, role) | source code
rowCount(self, index=None) | source code
columnCount(self, index=None) | source code